#!/bin/bash
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
#Wrapper script that will call the scripts to create proxy user, store proxy credentials
#in OCS and assign rights to the proxy user to search in the contexts as mentioned in the
#afpdircxt.conf file

LOG_FILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"

user_id=`id -u`
if test $user_id -ne 0
then
        echo "afp_config_proxy.sh : Only root user can run this script" >> $LOG_FILE
        echo "afp_config_proxy.sh : Only root user can run this script"
        exit 1
fi

if test $# == 6
then
	afpProxyUser=$1 
	admindn=$2
	hostname=$3
	port=$4 
	ssl=$5
	addTrustee=$6

	#OES_DATA and OES_AFP_DATA are admin password and proxy user password respectively. They are passed as
	#environment variables.

	export OES_DATA     
	export OES_AFP_DATA

	sh /opt/novell/afptcpd/bin/afp_create_proxy_user.sh "$afpProxyUser" "$admindn" "$hostname" $port $ssl
	createUser=$?
	if [ $createUser == 0 ]
	then
		sh /opt/novell/afptcpd/bin/afp_update_proxy_cred.sh "$afpProxyUser"
		updateCred=$?
		if [ $updateCred == 0 ]
		then
			sh /opt/novell/afptcpd/bin/afp_proxy_rights_assign.sh -u "$afpProxyUser" -d "$admindn" -i "$hostname" -p $port -s $ssl -r $addTrustee
			rightsAssign=$?
			if test $rightsAssign != 0
			then
				exit $rightsAssign
			fi
		else
			exit $updateCred
		fi
	else
		exit $createUser
	fi

	# Enable syslog service for afp
	systemctl restart rsyslog.service &> /dev/null

	# Starting the AFP service if not already running
	# If running then restart the service, because proxy details
	# might have changed
	rcnovell-afptcpd status 1>&2 > /dev/null
	if [ $? != "0" ]; then
		rcnovell-afptcpd start 1>&2 > /dev/null
	else
		rcnovell-afptcpd restart 1>&2 > /dev/null
	fi

else
	echo "Usage: afp_config_proxy.sh <proxy_fdn> <bind_fdn> <ldapserver_ip> <ldap_port> <SSL/NonSSL> <Add/Don't Add Proxy user as a trustee>"; >> $LOG_FILE
	echo "Usage: afp_config_proxy.sh <proxy_fdn> <bind_fdn> <ldapserver_ip> <ldap_port> <SSL/NonSSL> <Add/Don't Add Proxy user as a trustee>";
	exit 1
fi
exit 0


