#!/bin/bash
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
#Script to add proxy user as a trustee of the contexts as mentioned in the afpdircxt.conf file

LDAP_MOD_BIN="/usr/bin/ldapmodify"
FILE="/etc/opt/novell/afptcpd/afpdircxt.conf"
LOG_FILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
AFP_YAST_CONF_FILE="/etc/sysconfig/novell/afp_oes2018_sp3"

#Common Proxy framework will export admin credentials as OES_ADMIN_DATA and YAST will export the same as OES_DATA.
#So, if OES_ADMIN_DATA is not null then set OES_DATA to OES_ADMIN_DATA. Otherwise (in case if called from YAST) OES_DATA will
#already be set
if [ -n "$OES_ADMIN_DATA" ]; then
	OES_DATA="$OES_ADMIN_DATA"
fi

user_id=`id -u`
if test $user_id -ne 0
then
	echo "afp_proxy_rights_assign.sh: Only root user can run this script"
	exit 1
fi

#Help of the script
Usage()
{
        echo ""
        echo "Usage: afp_proxy_rights_assign.sh [options]"
        echo "          -h                      Prints this summary"
        echo "          -d                      LDAP Admin FDN"
        echo "          -u                      Proxy DN in LDAP format"
        echo "          -i                      LDAP Server IP address"
        echo "          -p                      LDAP Port"
        echo "          -s                      SSL or Not(1 or 0). Default 1"
        echo "          -r                      (Optional) 0,1. Default 1"
        echo "                                  0 - Don't add proxy user as trustee of User Contexts"
        echo "                                  1 - Add Proxy user as trustee of User Contexts"
        echo ""
        exit 4;
}

#Read the command line arguments and store them
while getopts d:i:p:u:s:r:h o
do
        case "$o" in
                        d)LDAP_ADM="$OPTARG";;
                        i)LDAP_IP="$OPTARG";;
                        p)LDAP_PORT="$OPTARG";;
                        u)PROXYUSER="$OPTARG";;
                        s)SSLORNOT="$OPTARG";;
                        r)ADDTRUSTEE="$OPTARG";;
                        h)Usage;;
                        [?]) Usage;;
        esac
done

if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = "" || test "$PROXYUSER" = "" || test "$SSLORNOT" = ""
then
        Usage
fi

afpProxyUser=$PROXYUSER
afpPassword="$OES_AFP_DATA"
adminDN=$LDAP_ADM
password="$OES_DATA"
hostname=$LDAP_IP
port=$LDAP_PORT
ssl=$SSLORNOT

# Function that makes AFP Proxy User a trustee of the context,read from the afpdircxt.conf file
set_context_trustee()
{
   TMP_LDIF_TRUSTEE="/tmp/afp_trustee.ldif"

   mkdir -p /tmp
   touch $TMP_LDIF_TRUSTEE
   ATTR_RDCMP="03"
   ATTR_INHERIT="01"

   echo "dn:$serverContext" > $TMP_LDIF_TRUSTEE
   echo "changetype: modify" >> $TMP_LDIF_TRUSTEE
   echo "add: acl" >> $TMP_LDIF_TRUSTEE
   echo "acl: $ATTR_RDCMP#subtree#$afpProxyUser#CN" >> $TMP_LDIF_TRUSTEE

   echo "Setting context trustee" >> $LOG_FILE

   if [ $ssl != 0 ]
   then
	   var=`env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem $LDAP_MOD_BIN -a -f $TMP_LDIF_TRUSTEE -c -H "ldaps://$hostname:$port" -D "$adminDN"  -w "$password"` >>$LOG_FILE 2>&1
   else
	   var=`env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem $LDAP_MOD_BIN -a -f $TMP_LDIF_TRUSTEE -c -H "ldap://$hostname:$port" -D "$adminDN"  -w "$password"` >>$LOG_FILE 2>&1
   fi
   contextTrusteeRet=$?
   if test $contextTrusteeRet == 20
        then
	   echo "Proxy user $afpProxyUser is already trustee of container $serverContext"
           contextTrusteeRet=0;
   fi
   echo -e "Setting context trustee done $var \n Return Value : $contextTrusteeRet \n" >> $LOG_FILE
   echo "Setting context trustee done $var \n Return Value : $contextTrusteeRet \n"
   rm -f $TMP_LDIF_TRUSTEE


}

# make sure file exists and readable
if [ ! -f $FILE ]; then
	echo "$FILE : does not exists"
	exit 2
elif [ ! -r $FILE ]; then
	echo "$FILE: can not read"
	exit 3
fi

usercontext_rights=1
if test "$ADDTRUSTEE" != ""
then
        usercontext_rights=$ADDTRUSTEE
else
        grep "CONFIG_AFP_USERCONTEXT_RIGHTS" $AFP_YAST_CONF_FILE | grep -i "no" >> /dev/null
        FOUNDOPTION=$?
        if test $FOUNDOPTION == 0
        then
                usercontext_rights=0
        fi
fi

# read $FILE using the file descriptors
# Set loop separator to end of line
# Add proxy as trustee of user contexts or no
if test $usercontext_rights == 1
then
	BAKIFS=$IFS
	IFS=$(echo -en "\n\b")
	exec 3<&0
	exec 0<$FILE
	while read line
	do
		c=`echo "$line" | sed -e 's/^[ \t]*//' | head -c 1`
		if [ "$c" = "#" ];then
			continue
		fi
		serverContext=`echo $line | tr . , `
		set_context_trustee
		if test $contextTrusteeRet != 0; then
			echo "Proxy user $afpProxyUser couldn't be given rights over context $serverContext" >> $LOG_FILE
       	         echo "Rights assignment to the AFP Proxy User Failed. Check log for more details"
			exec 0<&3
			IFS=$BAKIFS
			exit $contextTrusteeRet
		fi
	done
	exec 0<&3
	# restore $IFS which was used to determine what the field separators are
	IFS=$BAKIFS
else
        echo "Proxy user $afpProxyUser is not added as trustee of user contexts" >> $LOG_FILE
        echo "Proxy user $afpProxyUser is not added as trustee of user contexts"
fi

exit 0
